You are viewing a plain text version of this content. The canonical link for it is here.
Posted to fop-commits@xmlgraphics.apache.org by me...@apache.org on 2012/07/05 11:36:27 UTC

svn commit: r1357527 - in /xmlgraphics/fop/trunk/test/java/org/apache/fop/apps: FopConfBuilder.java FopConfParserTestCase.java

Author: mehdi
Date: Thu Jul  5 09:36:27 2012
New Revision: 1357527

URL: http://svn.apache.org/viewvc?rev=1357527&view=rev
Log:
Added test for strict user configuration setting within the fop-conf

Modified:
    xmlgraphics/fop/trunk/test/java/org/apache/fop/apps/FopConfBuilder.java
    xmlgraphics/fop/trunk/test/java/org/apache/fop/apps/FopConfParserTestCase.java

Modified: xmlgraphics/fop/trunk/test/java/org/apache/fop/apps/FopConfBuilder.java
URL: http://svn.apache.org/viewvc/xmlgraphics/fop/trunk/test/java/org/apache/fop/apps/FopConfBuilder.java?rev=1357527&r1=1357526&r2=1357527&view=diff
==============================================================================
--- xmlgraphics/fop/trunk/test/java/org/apache/fop/apps/FopConfParserTestCase.java (original)
+++ xmlgraphics/fop/trunk/test/java/org/apache/fop/apps/FopConfParserTestCase.java Thu Jul  5 09:36:27 2012
@@ -75,12 +75,18 @@ public class FopConfParserTestCase {
     }
 
     @Test
-    public void testStrictUserConfigValidation() {
+    public void testStrictFOValidation() {
         builder.setStrictValidation(false);
         assertFalse(buildFactory().validateStrictly());
     }
 
     @Test
+    public void testStrictUserValidation() {
+        builder.setStrictConfiguration(false);
+        assertFalse(buildFactory().validateUserConfigStrictly());
+    }
+
+    @Test
     public void testAccessibility() {
         builder.setAccessibility(false);
         assertFalse(buildFactory().isAccessibilityEnabled());



---------------------------------------------------------------------
To unsubscribe, e-mail: fop-commits-unsubscribe@xmlgraphics.apache.org
For additional commands, e-mail: fop-commits-help@xmlgraphics.apache.org
--- xmlgraphics/fop/trunk/test/java/org/apache/fop/apps/FopConfBuilder.java (original)
+++ xmlgraphics/fop/trunk/test/java/org/apache/fop/apps/FopConfBuilder.java Thu Jul  5 09:36:27 2012
@@ -113,7 +113,17 @@ public class FopConfBuilder implements F
     /**
      * Set the <strict-validation> tag within the fop.xconf.
      *
-     * @param validateStrictly true to enforce strict validation
+     * @param validateStrictly true to enforce strict FO validation
+     * @return <b>this</b>
+     */
+    public FopConfBuilder setStrictConfiguration(boolean validateStrictly) {
+        return createElement("strict-configuration", String.valueOf(validateStrictly));
+    }
+
+    /**
+     * Set the &lt;strict-validation&gt; tag within the fop.xconf.
+     *
+     * @param validateStrictly true to enforce strict configuration validation
      * @return <b>this</b>
      */
     public FopConfBuilder setStrictValidation(boolean validateStrictly) {

Modified: xmlgraphics/fop/trunk/test/java/org/apache/fop/apps/FopConfParserTestCase.java
URL: http://svn.apache.org/viewvc/xmlgraphics/fop/trunk/test/java/org/apache/fop/apps/FopConfParserTestCase.java?rev=1357527&r1=1357526&r2=1357527&view=diff
==============================================================================